# coding: utf-8

"""
    ecs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class RunInstancesRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auto_renew': 'bool',
        'auto_renew_period': 'int',
        'client_token': 'str',
        'count': 'int',
        'credit_specification': 'str',
        'deployment_set_id': 'str',
        'description': 'str',
        'dry_run': 'bool',
        'host_name': 'str',
        'hostname': 'str',
        'hpc_cluster_id': 'str',
        'image_id': 'str',
        'instance_charge_type': 'str',
        'instance_name': 'str',
        'instance_type': 'str',
        'instance_type_id': 'str',
        'keep_image_credential': 'bool',
        'key_pair_name': 'str',
        'min_count': 'int',
        'network_interfaces': 'list[NetworkInterfaceForRunInstancesInput]',
        'password': 'str',
        'period': 'int',
        'period_unit': 'str',
        'project_name': 'str',
        'security_enhancement_strategy': 'str',
        'spot_strategy': 'str',
        'suffix_index': 'int',
        'tags': 'list[TagForRunInstancesInput]',
        'unique_suffix': 'bool',
        'user_data': 'str',
        'volumes': 'list[VolumeForRunInstancesInput]',
        'zone_id': 'str'
    }

    attribute_map = {
        'auto_renew': 'AutoRenew',
        'auto_renew_period': 'AutoRenewPeriod',
        'client_token': 'ClientToken',
        'count': 'Count',
        'credit_specification': 'CreditSpecification',
        'deployment_set_id': 'DeploymentSetId',
        'description': 'Description',
        'dry_run': 'DryRun',
        'host_name': 'HostName',
        'hostname': 'Hostname',
        'hpc_cluster_id': 'HpcClusterId',
        'image_id': 'ImageId',
        'instance_charge_type': 'InstanceChargeType',
        'instance_name': 'InstanceName',
        'instance_type': 'InstanceType',
        'instance_type_id': 'InstanceTypeId',
        'keep_image_credential': 'KeepImageCredential',
        'key_pair_name': 'KeyPairName',
        'min_count': 'MinCount',
        'network_interfaces': 'NetworkInterfaces',
        'password': 'Password',
        'period': 'Period',
        'period_unit': 'PeriodUnit',
        'project_name': 'ProjectName',
        'security_enhancement_strategy': 'SecurityEnhancementStrategy',
        'spot_strategy': 'SpotStrategy',
        'suffix_index': 'SuffixIndex',
        'tags': 'Tags',
        'unique_suffix': 'UniqueSuffix',
        'user_data': 'UserData',
        'volumes': 'Volumes',
        'zone_id': 'ZoneId'
    }

    def __init__(self, auto_renew=None, auto_renew_period=None, client_token=None, count=None, credit_specification=None, deployment_set_id=None, description=None, dry_run=None, host_name=None, hostname=None, hpc_cluster_id=None, image_id=None, instance_charge_type=None, instance_name=None, instance_type=None, instance_type_id=None, keep_image_credential=None, key_pair_name=None, min_count=None, network_interfaces=None, password=None, period=None, period_unit=None, project_name=None, security_enhancement_strategy=None, spot_strategy=None, suffix_index=None, tags=None, unique_suffix=None, user_data=None, volumes=None, zone_id=None, _configuration=None):  # noqa: E501
        """RunInstancesRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._auto_renew = None
        self._auto_renew_period = None
        self._client_token = None
        self._count = None
        self._credit_specification = None
        self._deployment_set_id = None
        self._description = None
        self._dry_run = None
        self._host_name = None
        self._hostname = None
        self._hpc_cluster_id = None
        self._image_id = None
        self._instance_charge_type = None
        self._instance_name = None
        self._instance_type = None
        self._instance_type_id = None
        self._keep_image_credential = None
        self._key_pair_name = None
        self._min_count = None
        self._network_interfaces = None
        self._password = None
        self._period = None
        self._period_unit = None
        self._project_name = None
        self._security_enhancement_strategy = None
        self._spot_strategy = None
        self._suffix_index = None
        self._tags = None
        self._unique_suffix = None
        self._user_data = None
        self._volumes = None
        self._zone_id = None
        self.discriminator = None

        if auto_renew is not None:
            self.auto_renew = auto_renew
        if auto_renew_period is not None:
            self.auto_renew_period = auto_renew_period
        if client_token is not None:
            self.client_token = client_token
        if count is not None:
            self.count = count
        if credit_specification is not None:
            self.credit_specification = credit_specification
        if deployment_set_id is not None:
            self.deployment_set_id = deployment_set_id
        if description is not None:
            self.description = description
        if dry_run is not None:
            self.dry_run = dry_run
        if host_name is not None:
            self.host_name = host_name
        if hostname is not None:
            self.hostname = hostname
        if hpc_cluster_id is not None:
            self.hpc_cluster_id = hpc_cluster_id
        if image_id is not None:
            self.image_id = image_id
        if instance_charge_type is not None:
            self.instance_charge_type = instance_charge_type
        if instance_name is not None:
            self.instance_name = instance_name
        if instance_type is not None:
            self.instance_type = instance_type
        if instance_type_id is not None:
            self.instance_type_id = instance_type_id
        if keep_image_credential is not None:
            self.keep_image_credential = keep_image_credential
        if key_pair_name is not None:
            self.key_pair_name = key_pair_name
        if min_count is not None:
            self.min_count = min_count
        if network_interfaces is not None:
            self.network_interfaces = network_interfaces
        if password is not None:
            self.password = password
        if period is not None:
            self.period = period
        if period_unit is not None:
            self.period_unit = period_unit
        if project_name is not None:
            self.project_name = project_name
        if security_enhancement_strategy is not None:
            self.security_enhancement_strategy = security_enhancement_strategy
        if spot_strategy is not None:
            self.spot_strategy = spot_strategy
        if suffix_index is not None:
            self.suffix_index = suffix_index
        if tags is not None:
            self.tags = tags
        if unique_suffix is not None:
            self.unique_suffix = unique_suffix
        if user_data is not None:
            self.user_data = user_data
        if volumes is not None:
            self.volumes = volumes
        if zone_id is not None:
            self.zone_id = zone_id

    @property
    def auto_renew(self):
        """Gets the auto_renew of this RunInstancesRequest.  # noqa: E501


        :return: The auto_renew of this RunInstancesRequest.  # noqa: E501
        :rtype: bool
        """
        return self._auto_renew

    @auto_renew.setter
    def auto_renew(self, auto_renew):
        """Sets the auto_renew of this RunInstancesRequest.


        :param auto_renew: The auto_renew of this RunInstancesRequest.  # noqa: E501
        :type: bool
        """

        self._auto_renew = auto_renew

    @property
    def auto_renew_period(self):
        """Gets the auto_renew_period of this RunInstancesRequest.  # noqa: E501


        :return: The auto_renew_period of this RunInstancesRequest.  # noqa: E501
        :rtype: int
        """
        return self._auto_renew_period

    @auto_renew_period.setter
    def auto_renew_period(self, auto_renew_period):
        """Sets the auto_renew_period of this RunInstancesRequest.


        :param auto_renew_period: The auto_renew_period of this RunInstancesRequest.  # noqa: E501
        :type: int
        """

        self._auto_renew_period = auto_renew_period

    @property
    def client_token(self):
        """Gets the client_token of this RunInstancesRequest.  # noqa: E501


        :return: The client_token of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_token

    @client_token.setter
    def client_token(self, client_token):
        """Sets the client_token of this RunInstancesRequest.


        :param client_token: The client_token of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._client_token = client_token

    @property
    def count(self):
        """Gets the count of this RunInstancesRequest.  # noqa: E501


        :return: The count of this RunInstancesRequest.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this RunInstancesRequest.


        :param count: The count of this RunInstancesRequest.  # noqa: E501
        :type: int
        """

        self._count = count

    @property
    def credit_specification(self):
        """Gets the credit_specification of this RunInstancesRequest.  # noqa: E501


        :return: The credit_specification of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._credit_specification

    @credit_specification.setter
    def credit_specification(self, credit_specification):
        """Sets the credit_specification of this RunInstancesRequest.


        :param credit_specification: The credit_specification of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._credit_specification = credit_specification

    @property
    def deployment_set_id(self):
        """Gets the deployment_set_id of this RunInstancesRequest.  # noqa: E501


        :return: The deployment_set_id of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._deployment_set_id

    @deployment_set_id.setter
    def deployment_set_id(self, deployment_set_id):
        """Sets the deployment_set_id of this RunInstancesRequest.


        :param deployment_set_id: The deployment_set_id of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._deployment_set_id = deployment_set_id

    @property
    def description(self):
        """Gets the description of this RunInstancesRequest.  # noqa: E501


        :return: The description of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this RunInstancesRequest.


        :param description: The description of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def dry_run(self):
        """Gets the dry_run of this RunInstancesRequest.  # noqa: E501


        :return: The dry_run of this RunInstancesRequest.  # noqa: E501
        :rtype: bool
        """
        return self._dry_run

    @dry_run.setter
    def dry_run(self, dry_run):
        """Sets the dry_run of this RunInstancesRequest.


        :param dry_run: The dry_run of this RunInstancesRequest.  # noqa: E501
        :type: bool
        """

        self._dry_run = dry_run

    @property
    def host_name(self):
        """Gets the host_name of this RunInstancesRequest.  # noqa: E501


        :return: The host_name of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._host_name

    @host_name.setter
    def host_name(self, host_name):
        """Sets the host_name of this RunInstancesRequest.


        :param host_name: The host_name of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._host_name = host_name

    @property
    def hostname(self):
        """Gets the hostname of this RunInstancesRequest.  # noqa: E501


        :return: The hostname of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """Sets the hostname of this RunInstancesRequest.


        :param hostname: The hostname of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._hostname = hostname

    @property
    def hpc_cluster_id(self):
        """Gets the hpc_cluster_id of this RunInstancesRequest.  # noqa: E501


        :return: The hpc_cluster_id of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._hpc_cluster_id

    @hpc_cluster_id.setter
    def hpc_cluster_id(self, hpc_cluster_id):
        """Sets the hpc_cluster_id of this RunInstancesRequest.


        :param hpc_cluster_id: The hpc_cluster_id of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._hpc_cluster_id = hpc_cluster_id

    @property
    def image_id(self):
        """Gets the image_id of this RunInstancesRequest.  # noqa: E501


        :return: The image_id of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """Sets the image_id of this RunInstancesRequest.


        :param image_id: The image_id of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._image_id = image_id

    @property
    def instance_charge_type(self):
        """Gets the instance_charge_type of this RunInstancesRequest.  # noqa: E501


        :return: The instance_charge_type of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_charge_type

    @instance_charge_type.setter
    def instance_charge_type(self, instance_charge_type):
        """Sets the instance_charge_type of this RunInstancesRequest.


        :param instance_charge_type: The instance_charge_type of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._instance_charge_type = instance_charge_type

    @property
    def instance_name(self):
        """Gets the instance_name of this RunInstancesRequest.  # noqa: E501


        :return: The instance_name of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this RunInstancesRequest.


        :param instance_name: The instance_name of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._instance_name = instance_name

    @property
    def instance_type(self):
        """Gets the instance_type of this RunInstancesRequest.  # noqa: E501


        :return: The instance_type of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_type

    @instance_type.setter
    def instance_type(self, instance_type):
        """Sets the instance_type of this RunInstancesRequest.


        :param instance_type: The instance_type of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._instance_type = instance_type

    @property
    def instance_type_id(self):
        """Gets the instance_type_id of this RunInstancesRequest.  # noqa: E501


        :return: The instance_type_id of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_type_id

    @instance_type_id.setter
    def instance_type_id(self, instance_type_id):
        """Sets the instance_type_id of this RunInstancesRequest.


        :param instance_type_id: The instance_type_id of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._instance_type_id = instance_type_id

    @property
    def keep_image_credential(self):
        """Gets the keep_image_credential of this RunInstancesRequest.  # noqa: E501


        :return: The keep_image_credential of this RunInstancesRequest.  # noqa: E501
        :rtype: bool
        """
        return self._keep_image_credential

    @keep_image_credential.setter
    def keep_image_credential(self, keep_image_credential):
        """Sets the keep_image_credential of this RunInstancesRequest.


        :param keep_image_credential: The keep_image_credential of this RunInstancesRequest.  # noqa: E501
        :type: bool
        """

        self._keep_image_credential = keep_image_credential

    @property
    def key_pair_name(self):
        """Gets the key_pair_name of this RunInstancesRequest.  # noqa: E501


        :return: The key_pair_name of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._key_pair_name

    @key_pair_name.setter
    def key_pair_name(self, key_pair_name):
        """Sets the key_pair_name of this RunInstancesRequest.


        :param key_pair_name: The key_pair_name of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._key_pair_name = key_pair_name

    @property
    def min_count(self):
        """Gets the min_count of this RunInstancesRequest.  # noqa: E501


        :return: The min_count of this RunInstancesRequest.  # noqa: E501
        :rtype: int
        """
        return self._min_count

    @min_count.setter
    def min_count(self, min_count):
        """Sets the min_count of this RunInstancesRequest.


        :param min_count: The min_count of this RunInstancesRequest.  # noqa: E501
        :type: int
        """

        self._min_count = min_count

    @property
    def network_interfaces(self):
        """Gets the network_interfaces of this RunInstancesRequest.  # noqa: E501


        :return: The network_interfaces of this RunInstancesRequest.  # noqa: E501
        :rtype: list[NetworkInterfaceForRunInstancesInput]
        """
        return self._network_interfaces

    @network_interfaces.setter
    def network_interfaces(self, network_interfaces):
        """Sets the network_interfaces of this RunInstancesRequest.


        :param network_interfaces: The network_interfaces of this RunInstancesRequest.  # noqa: E501
        :type: list[NetworkInterfaceForRunInstancesInput]
        """

        self._network_interfaces = network_interfaces

    @property
    def password(self):
        """Gets the password of this RunInstancesRequest.  # noqa: E501


        :return: The password of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this RunInstancesRequest.


        :param password: The password of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def period(self):
        """Gets the period of this RunInstancesRequest.  # noqa: E501


        :return: The period of this RunInstancesRequest.  # noqa: E501
        :rtype: int
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this RunInstancesRequest.


        :param period: The period of this RunInstancesRequest.  # noqa: E501
        :type: int
        """

        self._period = period

    @property
    def period_unit(self):
        """Gets the period_unit of this RunInstancesRequest.  # noqa: E501


        :return: The period_unit of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._period_unit

    @period_unit.setter
    def period_unit(self, period_unit):
        """Sets the period_unit of this RunInstancesRequest.


        :param period_unit: The period_unit of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._period_unit = period_unit

    @property
    def project_name(self):
        """Gets the project_name of this RunInstancesRequest.  # noqa: E501


        :return: The project_name of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this RunInstancesRequest.


        :param project_name: The project_name of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def security_enhancement_strategy(self):
        """Gets the security_enhancement_strategy of this RunInstancesRequest.  # noqa: E501


        :return: The security_enhancement_strategy of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._security_enhancement_strategy

    @security_enhancement_strategy.setter
    def security_enhancement_strategy(self, security_enhancement_strategy):
        """Sets the security_enhancement_strategy of this RunInstancesRequest.


        :param security_enhancement_strategy: The security_enhancement_strategy of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._security_enhancement_strategy = security_enhancement_strategy

    @property
    def spot_strategy(self):
        """Gets the spot_strategy of this RunInstancesRequest.  # noqa: E501


        :return: The spot_strategy of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._spot_strategy

    @spot_strategy.setter
    def spot_strategy(self, spot_strategy):
        """Sets the spot_strategy of this RunInstancesRequest.


        :param spot_strategy: The spot_strategy of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._spot_strategy = spot_strategy

    @property
    def suffix_index(self):
        """Gets the suffix_index of this RunInstancesRequest.  # noqa: E501


        :return: The suffix_index of this RunInstancesRequest.  # noqa: E501
        :rtype: int
        """
        return self._suffix_index

    @suffix_index.setter
    def suffix_index(self, suffix_index):
        """Sets the suffix_index of this RunInstancesRequest.


        :param suffix_index: The suffix_index of this RunInstancesRequest.  # noqa: E501
        :type: int
        """

        self._suffix_index = suffix_index

    @property
    def tags(self):
        """Gets the tags of this RunInstancesRequest.  # noqa: E501


        :return: The tags of this RunInstancesRequest.  # noqa: E501
        :rtype: list[TagForRunInstancesInput]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this RunInstancesRequest.


        :param tags: The tags of this RunInstancesRequest.  # noqa: E501
        :type: list[TagForRunInstancesInput]
        """

        self._tags = tags

    @property
    def unique_suffix(self):
        """Gets the unique_suffix of this RunInstancesRequest.  # noqa: E501


        :return: The unique_suffix of this RunInstancesRequest.  # noqa: E501
        :rtype: bool
        """
        return self._unique_suffix

    @unique_suffix.setter
    def unique_suffix(self, unique_suffix):
        """Sets the unique_suffix of this RunInstancesRequest.


        :param unique_suffix: The unique_suffix of this RunInstancesRequest.  # noqa: E501
        :type: bool
        """

        self._unique_suffix = unique_suffix

    @property
    def user_data(self):
        """Gets the user_data of this RunInstancesRequest.  # noqa: E501


        :return: The user_data of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._user_data

    @user_data.setter
    def user_data(self, user_data):
        """Sets the user_data of this RunInstancesRequest.


        :param user_data: The user_data of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._user_data = user_data

    @property
    def volumes(self):
        """Gets the volumes of this RunInstancesRequest.  # noqa: E501


        :return: The volumes of this RunInstancesRequest.  # noqa: E501
        :rtype: list[VolumeForRunInstancesInput]
        """
        return self._volumes

    @volumes.setter
    def volumes(self, volumes):
        """Sets the volumes of this RunInstancesRequest.


        :param volumes: The volumes of this RunInstancesRequest.  # noqa: E501
        :type: list[VolumeForRunInstancesInput]
        """

        self._volumes = volumes

    @property
    def zone_id(self):
        """Gets the zone_id of this RunInstancesRequest.  # noqa: E501


        :return: The zone_id of this RunInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this RunInstancesRequest.


        :param zone_id: The zone_id of this RunInstancesRequest.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RunInstancesRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunInstancesRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RunInstancesRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding:utf-8

from volcenginesdkcore.configuration import Configuration
from volcenginesdkcore.api_client import ApiClient
from volcenginesdkcore.universal import UniversalApi, UniversalInfo
from volcenginesdkcore.flatten import Flatten



# coding: utf-8

"""
    ecs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DescribeSystemEventsRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at_end': 'str',
        'created_at_start': 'str',
        'event_ids': 'list[str]',
        'max_results': 'str',
        'next_token': 'str',
        'resource_ids': 'list[str]',
        'status': 'list[str]',
        'types': 'list[str]'
    }

    attribute_map = {
        'created_at_end': 'CreatedAtEnd',
        'created_at_start': 'CreatedAtStart',
        'event_ids': 'EventIds',
        'max_results': 'MaxResults',
        'next_token': 'NextToken',
        'resource_ids': 'ResourceIds',
        'status': 'Status',
        'types': 'Types'
    }

    def __init__(self, created_at_end=None, created_at_start=None, event_ids=None, max_results=None, next_token=None, resource_ids=None, status=None, types=None, _configuration=None):  # noqa: E501
        """DescribeSystemEventsRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._created_at_end = None
        self._created_at_start = None
        self._event_ids = None
        self._max_results = None
        self._next_token = None
        self._resource_ids = None
        self._status = None
        self._types = None
        self.discriminator = None

        if created_at_end is not None:
            self.created_at_end = created_at_end
        if created_at_start is not None:
            self.created_at_start = created_at_start
        if event_ids is not None:
            self.event_ids = event_ids
        if max_results is not None:
            self.max_results = max_results
        if next_token is not None:
            self.next_token = next_token
        if resource_ids is not None:
            self.resource_ids = resource_ids
        if status is not None:
            self.status = status
        if types is not None:
            self.types = types

    @property
    def created_at_end(self):
        """Gets the created_at_end of this DescribeSystemEventsRequest.  # noqa: E501


        :return: The created_at_end of this DescribeSystemEventsRequest.  # noqa: E501
        :rtype: str
        """
        return self._created_at_end

    @created_at_end.setter
    def created_at_end(self, created_at_end):
        """Sets the created_at_end of this DescribeSystemEventsRequest.


        :param created_at_end: The created_at_end of this DescribeSystemEventsRequest.  # noqa: E501
        :type: str
        """

        self._created_at_end = created_at_end

    @property
    def created_at_start(self):
        """Gets the created_at_start of this DescribeSystemEventsRequest.  # noqa: E501


        :return: The created_at_start of this DescribeSystemEventsRequest.  # noqa: E501
        :rtype: str
        """
        return self._created_at_start

    @created_at_start.setter
    def created_at_start(self, created_at_start):
        """Sets the created_at_start of this DescribeSystemEventsRequest.


        :param created_at_start: The created_at_start of this DescribeSystemEventsRequest.  # noqa: E501
        :type: str
        """

        self._created_at_start = created_at_start

    @property
    def event_ids(self):
        """Gets the event_ids of this DescribeSystemEventsRequest.  # noqa: E501


        :return: The event_ids of this DescribeSystemEventsRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._event_ids

    @event_ids.setter
    def event_ids(self, event_ids):
        """Sets the event_ids of this DescribeSystemEventsRequest.


        :param event_ids: The event_ids of this DescribeSystemEventsRequest.  # noqa: E501
        :type: list[str]
        """

        self._event_ids = event_ids

    @property
    def max_results(self):
        """Gets the max_results of this DescribeSystemEventsRequest.  # noqa: E501


        :return: The max_results of this DescribeSystemEventsRequest.  # noqa: E501
        :rtype: str
        """
        return self._max_results

    @max_results.setter
    def max_results(self, max_results):
        """Sets the max_results of this DescribeSystemEventsRequest.


        :param max_results: The max_results of this DescribeSystemEventsRequest.  # noqa: E501
        :type: str
        """

        self._max_results = max_results

    @property
    def next_token(self):
        """Gets the next_token of this DescribeSystemEventsRequest.  # noqa: E501


        :return: The next_token of this DescribeSystemEventsRequest.  # noqa: E501
        :rtype: str
        """
        return self._next_token

    @next_token.setter
    def next_token(self, next_token):
        """Sets the next_token of this DescribeSystemEventsRequest.


        :param next_token: The next_token of this DescribeSystemEventsRequest.  # noqa: E501
        :type: str
        """

        self._next_token = next_token

    @property
    def resource_ids(self):
        """Gets the resource_ids of this DescribeSystemEventsRequest.  # noqa: E501


        :return: The resource_ids of this DescribeSystemEventsRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._resource_ids

    @resource_ids.setter
    def resource_ids(self, resource_ids):
        """Sets the resource_ids of this DescribeSystemEventsRequest.


        :param resource_ids: The resource_ids of this DescribeSystemEventsRequest.  # noqa: E501
        :type: list[str]
        """

        self._resource_ids = resource_ids

    @property
    def status(self):
        """Gets the status of this DescribeSystemEventsRequest.  # noqa: E501


        :return: The status of this DescribeSystemEventsRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DescribeSystemEventsRequest.


        :param status: The status of this DescribeSystemEventsRequest.  # noqa: E501
        :type: list[str]
        """

        self._status = status

    @property
    def types(self):
        """Gets the types of this DescribeSystemEventsRequest.  # noqa: E501


        :return: The types of this DescribeSystemEventsRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._types

    @types.setter
    def types(self, types):
        """Sets the types of this DescribeSystemEventsRequest.


        :param types: The types of this DescribeSystemEventsRequest.  # noqa: E501
        :type: list[str]
        """

        self._types = types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescribeSystemEventsRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescribeSystemEventsRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DescribeSystemEventsRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ecs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class AvailableZoneForDescribeAvailableResourceOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'available_resources': 'list[AvailableResourceForDescribeAvailableResourceOutput]',
        'region_id': 'str',
        'status': 'str',
        'zone_id': 'str'
    }

    attribute_map = {
        'available_resources': 'AvailableResources',
        'region_id': 'RegionId',
        'status': 'Status',
        'zone_id': 'ZoneId'
    }

    def __init__(self, available_resources=None, region_id=None, status=None, zone_id=None, _configuration=None):  # noqa: E501
        """AvailableZoneForDescribeAvailableResourceOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._available_resources = None
        self._region_id = None
        self._status = None
        self._zone_id = None
        self.discriminator = None

        if available_resources is not None:
            self.available_resources = available_resources
        if region_id is not None:
            self.region_id = region_id
        if status is not None:
            self.status = status
        if zone_id is not None:
            self.zone_id = zone_id

    @property
    def available_resources(self):
        """Gets the available_resources of this AvailableZoneForDescribeAvailableResourceOutput.  # noqa: E501


        :return: The available_resources of this AvailableZoneForDescribeAvailableResourceOutput.  # noqa: E501
        :rtype: list[AvailableResourceForDescribeAvailableResourceOutput]
        """
        return self._available_resources

    @available_resources.setter
    def available_resources(self, available_resources):
        """Sets the available_resources of this AvailableZoneForDescribeAvailableResourceOutput.


        :param available_resources: The available_resources of this AvailableZoneForDescribeAvailableResourceOutput.  # noqa: E501
        :type: list[AvailableResourceForDescribeAvailableResourceOutput]
        """

        self._available_resources = available_resources

    @property
    def region_id(self):
        """Gets the region_id of this AvailableZoneForDescribeAvailableResourceOutput.  # noqa: E501


        :return: The region_id of this AvailableZoneForDescribeAvailableResourceOutput.  # noqa: E501
        :rtype: str
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        """Sets the region_id of this AvailableZoneForDescribeAvailableResourceOutput.


        :param region_id: The region_id of this AvailableZoneForDescribeAvailableResourceOutput.  # noqa: E501
        :type: str
        """

        self._region_id = region_id

    @property
    def status(self):
        """Gets the status of this AvailableZoneForDescribeAvailableResourceOutput.  # noqa: E501


        :return: The status of this AvailableZoneForDescribeAvailableResourceOutput.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this AvailableZoneForDescribeAvailableResourceOutput.


        :param status: The status of this AvailableZoneForDescribeAvailableResourceOutput.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def zone_id(self):
        """Gets the zone_id of this AvailableZoneForDescribeAvailableResourceOutput.  # noqa: E501


        :return: The zone_id of this AvailableZoneForDescribeAvailableResourceOutput.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this AvailableZoneForDescribeAvailableResourceOutput.


        :param zone_id: The zone_id of this AvailableZoneForDescribeAvailableResourceOutput.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AvailableZoneForDescribeAvailableResourceOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AvailableZoneForDescribeAvailableResourceOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AvailableZoneForDescribeAvailableResourceOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    cen

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class CreateCenBandwidthPackageRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bandwidth': 'int',
        'billing_type': 'int',
        'cen_bandwidth_package_name': 'str',
        'cen_id': 'str',
        'client_token': 'str',
        'description': 'str',
        'local_geographic_region_set_id': 'str',
        'peer_geographic_region_set_id': 'str',
        'period': 'int',
        'period_unit': 'str',
        'project_name': 'str',
        'tags': 'list[TagForCreateCenBandwidthPackageInput]'
    }

    attribute_map = {
        'bandwidth': 'Bandwidth',
        'billing_type': 'BillingType',
        'cen_bandwidth_package_name': 'CenBandwidthPackageName',
        'cen_id': 'CenId',
        'client_token': 'ClientToken',
        'description': 'Description',
        'local_geographic_region_set_id': 'LocalGeographicRegionSetId',
        'peer_geographic_region_set_id': 'PeerGeographicRegionSetId',
        'period': 'Period',
        'period_unit': 'PeriodUnit',
        'project_name': 'ProjectName',
        'tags': 'Tags'
    }

    def __init__(self, bandwidth=None, billing_type=None, cen_bandwidth_package_name=None, cen_id=None, client_token=None, description=None, local_geographic_region_set_id=None, peer_geographic_region_set_id=None, period=None, period_unit=None, project_name=None, tags=None, _configuration=None):  # noqa: E501
        """CreateCenBandwidthPackageRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._bandwidth = None
        self._billing_type = None
        self._cen_bandwidth_package_name = None
        self._cen_id = None
        self._client_token = None
        self._description = None
        self._local_geographic_region_set_id = None
        self._peer_geographic_region_set_id = None
        self._period = None
        self._period_unit = None
        self._project_name = None
        self._tags = None
        self.discriminator = None

        if bandwidth is not None:
            self.bandwidth = bandwidth
        if billing_type is not None:
            self.billing_type = billing_type
        if cen_bandwidth_package_name is not None:
            self.cen_bandwidth_package_name = cen_bandwidth_package_name
        if cen_id is not None:
            self.cen_id = cen_id
        if client_token is not None:
            self.client_token = client_token
        if description is not None:
            self.description = description
        self.local_geographic_region_set_id = local_geographic_region_set_id
        self.peer_geographic_region_set_id = peer_geographic_region_set_id
        if period is not None:
            self.period = period
        if period_unit is not None:
            self.period_unit = period_unit
        if project_name is not None:
            self.project_name = project_name
        if tags is not None:
            self.tags = tags

    @property
    def bandwidth(self):
        """Gets the bandwidth of this CreateCenBandwidthPackageRequest.  # noqa: E501


        :return: The bandwidth of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :rtype: int
        """
        return self._bandwidth

    @bandwidth.setter
    def bandwidth(self, bandwidth):
        """Sets the bandwidth of this CreateCenBandwidthPackageRequest.


        :param bandwidth: The bandwidth of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :type: int
        """

        self._bandwidth = bandwidth

    @property
    def billing_type(self):
        """Gets the billing_type of this CreateCenBandwidthPackageRequest.  # noqa: E501


        :return: The billing_type of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :rtype: int
        """
        return self._billing_type

    @billing_type.setter
    def billing_type(self, billing_type):
        """Sets the billing_type of this CreateCenBandwidthPackageRequest.


        :param billing_type: The billing_type of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :type: int
        """
        if (self._configuration.client_side_validation and
                billing_type is not None and billing_type > 4):  # noqa: E501
            raise ValueError("Invalid value for `billing_type`, must be a value less than or equal to `4`")  # noqa: E501
        if (self._configuration.client_side_validation and
                billing_type is not None and billing_type < 1):  # noqa: E501
            raise ValueError("Invalid value for `billing_type`, must be a value greater than or equal to `1`")  # noqa: E501

        self._billing_type = billing_type

    @property
    def cen_bandwidth_package_name(self):
        """Gets the cen_bandwidth_package_name of this CreateCenBandwidthPackageRequest.  # noqa: E501


        :return: The cen_bandwidth_package_name of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :rtype: str
        """
        return self._cen_bandwidth_package_name

    @cen_bandwidth_package_name.setter
    def cen_bandwidth_package_name(self, cen_bandwidth_package_name):
        """Sets the cen_bandwidth_package_name of this CreateCenBandwidthPackageRequest.


        :param cen_bandwidth_package_name: The cen_bandwidth_package_name of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                cen_bandwidth_package_name is not None and len(cen_bandwidth_package_name) > 128):
            raise ValueError("Invalid value for `cen_bandwidth_package_name`, length must be less than or equal to `128`")  # noqa: E501
        if (self._configuration.client_side_validation and
                cen_bandwidth_package_name is not None and len(cen_bandwidth_package_name) < 1):
            raise ValueError("Invalid value for `cen_bandwidth_package_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._cen_bandwidth_package_name = cen_bandwidth_package_name

    @property
    def cen_id(self):
        """Gets the cen_id of this CreateCenBandwidthPackageRequest.  # noqa: E501


        :return: The cen_id of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :rtype: str
        """
        return self._cen_id

    @cen_id.setter
    def cen_id(self, cen_id):
        """Sets the cen_id of this CreateCenBandwidthPackageRequest.


        :param cen_id: The cen_id of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :type: str
        """

        self._cen_id = cen_id

    @property
    def client_token(self):
        """Gets the client_token of this CreateCenBandwidthPackageRequest.  # noqa: E501


        :return: The client_token of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_token

    @client_token.setter
    def client_token(self, client_token):
        """Sets the client_token of this CreateCenBandwidthPackageRequest.


        :param client_token: The client_token of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :type: str
        """

        self._client_token = client_token

    @property
    def description(self):
        """Gets the description of this CreateCenBandwidthPackageRequest.  # noqa: E501


        :return: The description of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateCenBandwidthPackageRequest.


        :param description: The description of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                description is not None and len(description) > 255):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `255`")  # noqa: E501
        if (self._configuration.client_side_validation and
                description is not None and len(description) < 1):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `1`")  # noqa: E501

        self._description = description

    @property
    def local_geographic_region_set_id(self):
        """Gets the local_geographic_region_set_id of this CreateCenBandwidthPackageRequest.  # noqa: E501


        :return: The local_geographic_region_set_id of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :rtype: str
        """
        return self._local_geographic_region_set_id

    @local_geographic_region_set_id.setter
    def local_geographic_region_set_id(self, local_geographic_region_set_id):
        """Sets the local_geographic_region_set_id of this CreateCenBandwidthPackageRequest.


        :param local_geographic_region_set_id: The local_geographic_region_set_id of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and local_geographic_region_set_id is None:
            raise ValueError("Invalid value for `local_geographic_region_set_id`, must not be `None`")  # noqa: E501

        self._local_geographic_region_set_id = local_geographic_region_set_id

    @property
    def peer_geographic_region_set_id(self):
        """Gets the peer_geographic_region_set_id of this CreateCenBandwidthPackageRequest.  # noqa: E501


        :return: The peer_geographic_region_set_id of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :rtype: str
        """
        return self._peer_geographic_region_set_id

    @peer_geographic_region_set_id.setter
    def peer_geographic_region_set_id(self, peer_geographic_region_set_id):
        """Sets the peer_geographic_region_set_id of this CreateCenBandwidthPackageRequest.


        :param peer_geographic_region_set_id: The peer_geographic_region_set_id of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and peer_geographic_region_set_id is None:
            raise ValueError("Invalid value for `peer_geographic_region_set_id`, must not be `None`")  # noqa: E501

        self._peer_geographic_region_set_id = peer_geographic_region_set_id

    @property
    def period(self):
        """Gets the period of this CreateCenBandwidthPackageRequest.  # noqa: E501


        :return: The period of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :rtype: int
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this CreateCenBandwidthPackageRequest.


        :param period: The period of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :type: int
        """

        self._period = period

    @property
    def period_unit(self):
        """Gets the period_unit of this CreateCenBandwidthPackageRequest.  # noqa: E501


        :return: The period_unit of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :rtype: str
        """
        return self._period_unit

    @period_unit.setter
    def period_unit(self, period_unit):
        """Sets the period_unit of this CreateCenBandwidthPackageRequest.


        :param period_unit: The period_unit of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["Moth", "Year"]  # noqa: E501
        if (self._configuration.client_side_validation and
                period_unit not in allowed_values):
            raise ValueError(
                "Invalid value for `period_unit` ({0}), must be one of {1}"  # noqa: E501
                .format(period_unit, allowed_values)
            )

        self._period_unit = period_unit

    @property
    def project_name(self):
        """Gets the project_name of this CreateCenBandwidthPackageRequest.  # noqa: E501


        :return: The project_name of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this CreateCenBandwidthPackageRequest.


        :param project_name: The project_name of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def tags(self):
        """Gets the tags of this CreateCenBandwidthPackageRequest.  # noqa: E501


        :return: The tags of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :rtype: list[TagForCreateCenBandwidthPackageInput]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this CreateCenBandwidthPackageRequest.


        :param tags: The tags of this CreateCenBandwidthPackageRequest.  # noqa: E501
        :type: list[TagForCreateCenBandwidthPackageInput]
        """

        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateCenBandwidthPackageRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateCenBandwidthPackageRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateCenBandwidthPackageRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    rds_mysql_v2

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class EndpointForDescribeDBInstanceDetailOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'addresses': 'list[AddressForDescribeDBInstanceDetailOutput]',
        'auto_add_new_nodes': 'str',
        'description': 'str',
        'enable_read_only': 'str',
        'enable_read_write_splitting': 'str',
        'endpoint_id': 'str',
        'endpoint_name': 'str',
        'endpoint_type': 'str',
        'read_only_node_weight': 'list[ReadOnlyNodeWeightForDescribeDBInstanceDetailOutput]',
        'read_write_mode': 'str'
    }

    attribute_map = {
        'addresses': 'Addresses',
        'auto_add_new_nodes': 'AutoAddNewNodes',
        'description': 'Description',
        'enable_read_only': 'EnableReadOnly',
        'enable_read_write_splitting': 'EnableReadWriteSplitting',
        'endpoint_id': 'EndpointId',
        'endpoint_name': 'EndpointName',
        'endpoint_type': 'EndpointType',
        'read_only_node_weight': 'ReadOnlyNodeWeight',
        'read_write_mode': 'ReadWriteMode'
    }

    def __init__(self, addresses=None, auto_add_new_nodes=None, description=None, enable_read_only=None, enable_read_write_splitting=None, endpoint_id=None, endpoint_name=None, endpoint_type=None, read_only_node_weight=None, read_write_mode=None, _configuration=None):  # noqa: E501
        """EndpointForDescribeDBInstanceDetailOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._addresses = None
        self._auto_add_new_nodes = None
        self._description = None
        self._enable_read_only = None
        self._enable_read_write_splitting = None
        self._endpoint_id = None
        self._endpoint_name = None
        self._endpoint_type = None
        self._read_only_node_weight = None
        self._read_write_mode = None
        self.discriminator = None

        if addresses is not None:
            self.addresses = addresses
        if auto_add_new_nodes is not None:
            self.auto_add_new_nodes = auto_add_new_nodes
        if description is not None:
            self.description = description
        if enable_read_only is not None:
            self.enable_read_only = enable_read_only
        if enable_read_write_splitting is not None:
            self.enable_read_write_splitting = enable_read_write_splitting
        if endpoint_id is not None:
            self.endpoint_id = endpoint_id
        if endpoint_name is not None:
            self.endpoint_name = endpoint_name
        if endpoint_type is not None:
            self.endpoint_type = endpoint_type
        if read_only_node_weight is not None:
            self.read_only_node_weight = read_only_node_weight
        if read_write_mode is not None:
            self.read_write_mode = read_write_mode

    @property
    def addresses(self):
        """Gets the addresses of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The addresses of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: list[AddressForDescribeDBInstanceDetailOutput]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """Sets the addresses of this EndpointForDescribeDBInstanceDetailOutput.


        :param addresses: The addresses of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: list[AddressForDescribeDBInstanceDetailOutput]
        """

        self._addresses = addresses

    @property
    def auto_add_new_nodes(self):
        """Gets the auto_add_new_nodes of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The auto_add_new_nodes of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._auto_add_new_nodes

    @auto_add_new_nodes.setter
    def auto_add_new_nodes(self, auto_add_new_nodes):
        """Sets the auto_add_new_nodes of this EndpointForDescribeDBInstanceDetailOutput.


        :param auto_add_new_nodes: The auto_add_new_nodes of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._auto_add_new_nodes = auto_add_new_nodes

    @property
    def description(self):
        """Gets the description of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The description of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this EndpointForDescribeDBInstanceDetailOutput.


        :param description: The description of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def enable_read_only(self):
        """Gets the enable_read_only of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The enable_read_only of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._enable_read_only

    @enable_read_only.setter
    def enable_read_only(self, enable_read_only):
        """Sets the enable_read_only of this EndpointForDescribeDBInstanceDetailOutput.


        :param enable_read_only: The enable_read_only of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._enable_read_only = enable_read_only

    @property
    def enable_read_write_splitting(self):
        """Gets the enable_read_write_splitting of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The enable_read_write_splitting of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._enable_read_write_splitting

    @enable_read_write_splitting.setter
    def enable_read_write_splitting(self, enable_read_write_splitting):
        """Sets the enable_read_write_splitting of this EndpointForDescribeDBInstanceDetailOutput.


        :param enable_read_write_splitting: The enable_read_write_splitting of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._enable_read_write_splitting = enable_read_write_splitting

    @property
    def endpoint_id(self):
        """Gets the endpoint_id of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The endpoint_id of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._endpoint_id

    @endpoint_id.setter
    def endpoint_id(self, endpoint_id):
        """Sets the endpoint_id of this EndpointForDescribeDBInstanceDetailOutput.


        :param endpoint_id: The endpoint_id of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._endpoint_id = endpoint_id

    @property
    def endpoint_name(self):
        """Gets the endpoint_name of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The endpoint_name of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._endpoint_name

    @endpoint_name.setter
    def endpoint_name(self, endpoint_name):
        """Sets the endpoint_name of this EndpointForDescribeDBInstanceDetailOutput.


        :param endpoint_name: The endpoint_name of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._endpoint_name = endpoint_name

    @property
    def endpoint_type(self):
        """Gets the endpoint_type of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The endpoint_type of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._endpoint_type

    @endpoint_type.setter
    def endpoint_type(self, endpoint_type):
        """Sets the endpoint_type of this EndpointForDescribeDBInstanceDetailOutput.


        :param endpoint_type: The endpoint_type of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._endpoint_type = endpoint_type

    @property
    def read_only_node_weight(self):
        """Gets the read_only_node_weight of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The read_only_node_weight of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: list[ReadOnlyNodeWeightForDescribeDBInstanceDetailOutput]
        """
        return self._read_only_node_weight

    @read_only_node_weight.setter
    def read_only_node_weight(self, read_only_node_weight):
        """Sets the read_only_node_weight of this EndpointForDescribeDBInstanceDetailOutput.


        :param read_only_node_weight: The read_only_node_weight of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: list[ReadOnlyNodeWeightForDescribeDBInstanceDetailOutput]
        """

        self._read_only_node_weight = read_only_node_weight

    @property
    def read_write_mode(self):
        """Gets the read_write_mode of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The read_write_mode of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._read_write_mode

    @read_write_mode.setter
    def read_write_mode(self, read_write_mode):
        """Sets the read_write_mode of this EndpointForDescribeDBInstanceDetailOutput.


        :param read_write_mode: The read_write_mode of this EndpointForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._read_write_mode = read_write_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EndpointForDescribeDBInstanceDetailOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EndpointForDescribeDBInstanceDetailOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EndpointForDescribeDBInstanceDetailOutput):
            return True

        return self.to_dict() != other.to_dict()
